Contributing
============

Project is hosted on `GitHub`_.

.. _GitHub: https://github.com/darkfeline/mir.xdg

Python code follows `PEP 8`_, including the first rule.

.. _PEP 8: https://www.python.org/dev/peps/pep-0008/
